@@ -124,6 +124,7 @@ tar_quarto <- function(
   debug = FALSE,
   quiet = TRUE,
   pandoc_args = NULL,
+  profile = NULL,
   tidy_eval = targets::tar_option_get("tidy_eval"),
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
@@ -153,6 +154,7 @@ tar_quarto <- function(
     debug = debug,
     quiet = quiet,
     pandoc_args = pandoc_args,
+    profile = profile,
     packages = packages,
     library = library,
     error = error,
