@@ -140,7 +140,7 @@ tar_quarto_rep_raw <- function(
   targets::tar_assert_nzchar(path)
   targets::tar_assert_path(path)
   targets::tar_assert_not_dirs(path)
-  targets::tar_assert_lang(execute_params)
+  targets::tar_assert_lang(execute_params %|||% quote(x))
   targets::tar_assert_dbl(batches %|||% 0L, "batches must be numeric.")
   targets::tar_assert_scalar(batches %|||% 0L, "batches must have length 1.")
   targets::tar_assert_chr(extra_files)
