@@ -104,6 +104,8 @@ tar_render <- function(
   packages = targets::tar_option_get("packages"),
   library = targets::tar_option_get("library"),
   error = targets::tar_option_get("error"),
+  memory = targets::tar_option_get("memory"),
+  garbage_collection = targets::tar_option_get("garbage_collection"),
   deployment = "main",
   priority = targets::tar_option_get("priority"),
   resources = targets::tar_option_get("resources"),
@@ -130,6 +132,8 @@ tar_render <- function(
     format = "file",
     repository = "local",
     error = error,
+    memory = memory,
+    garbage_collection = garbage_collection,
     deployment = deployment,
     priority = priority,
     resources = resources,
