@@ -1,5 +1,5 @@
 targets::tar_test("tar_knit() works", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
@@ -41,7 +41,7 @@ targets::tar_test("tar_knit() works", {
 })
 
 targets::tar_test("tar_knit() warns about tar_read_raw()", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
@@ -67,7 +67,7 @@ targets::tar_test("tar_knit() warns about tar_read_raw()", {
 })
 
 targets::tar_test("tar_knit() warns about tar_load_raw()", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
@@ -94,7 +94,7 @@ targets::tar_test("tar_knit() warns about tar_load_raw()", {
 })
 
 targets::tar_test("tar_knit(nested) runs from project root", {
-  skip_pandoc()
+  skip_rmarkdown()
   lines <- c(
     "---",
     "title: report",
